diff mbox

Input: xpad - Add PDP device id 0x02a4

Message ID 20180325125619.29191-1-frtherien@gmail.com (mailing list archive)
State Accepted
Headers show

Commit Message

Francis Therien March 25, 2018, 12:56 p.m. UTC
Adds support for a PDP Xbox One controller with device ID
(0x06ef:0x02a4). The Product string for this device is "PDP Wired
Controller for Xbox One - Stealth Series | Phantom Black".

Signed-off-by: Francis Therien <frtherien@gmail.com>
---
 drivers/input/joystick/xpad.c | 9 +++++++--
 1 file changed, 7 insertions(+), 2 deletions(-)

Comments

Dmitry Torokhov March 26, 2018, 11 p.m. UTC | #1
On Sun, Mar 25, 2018 at 08:56:19AM -0400, Francis Therien wrote:
> Adds support for a PDP Xbox One controller with device ID
> (0x06ef:0x02a4). The Product string for this device is "PDP Wired
> Controller for Xbox One - Stealth Series | Phantom Black".
> 
> Signed-off-by: Francis Therien <frtherien@gmail.com>

Applied, thank you.

> ---
>  drivers/input/joystick/xpad.c | 9 +++++++--
>  1 file changed, 7 insertions(+), 2 deletions(-)
> 
> diff --git a/drivers/input/joystick/xpad.c b/drivers/input/joystick/xpad.c
> index 9d2688f3f961..5402f488bdb9 100644
> --- a/drivers/input/joystick/xpad.c
> +++ b/drivers/input/joystick/xpad.c
> @@ -227,6 +227,7 @@ static const struct xpad_device {
>  	{ 0x0e6f, 0x021f, "Rock Candy Gamepad for Xbox 360", 0, XTYPE_XBOX360 },
>  	{ 0x0e6f, 0x0246, "Rock Candy Gamepad for Xbox One 2015", 0, XTYPE_XBOXONE },
>  	{ 0x0e6f, 0x02ab, "PDP Controller for Xbox One", 0, XTYPE_XBOXONE },
> +	{ 0x0e6f, 0x02a4, "PDP Wired Controller for Xbox One - Stealth Series", 0, XTYPE_XBOXONE },
>  	{ 0x0e6f, 0x0301, "Logic3 Controller", 0, XTYPE_XBOX360 },
>  	{ 0x0e6f, 0x0346, "Rock Candy Gamepad for Xbox One 2016", 0, XTYPE_XBOXONE },
>  	{ 0x0e6f, 0x0401, "Logic3 Controller", 0, XTYPE_XBOX360 },
> @@ -475,7 +476,8 @@ static const u8 xboxone_hori_init[] = {
>  
>  /*
>   * This packet is required for some of the PDP pads to start
> - * sending input reports. One of those pads is (0x0e6f:0x02ab).
> + * sending input reports. These pads include : (0x0e6f:0x02ab,
> + * 0x0e6f:0x02a4).
>   */
>  static const u8 xboxone_pdp_init1[] = {
>  	0x0a, 0x20, 0x00, 0x03, 0x00, 0x01, 0x14
> @@ -483,7 +485,8 @@ static const u8 xboxone_pdp_init1[] = {
>  
>  /*
>   * This packet is required for some of the PDP pads to start
> - * sending input reports. One of those pads is (0x0e6f:0x02ab).
> + * sending input reports. These pads include : (0x0e6f:0x02ab,
> + * 0x0e6f:0x02a4).
>   */
>  static const u8 xboxone_pdp_init2[] = {
>  	0x06, 0x20, 0x00, 0x02, 0x01, 0x00
> @@ -521,6 +524,8 @@ static const struct xboxone_init_packet xboxone_init_packets[] = {
>  	XBOXONE_INIT_PKT(0x0000, 0x0000, xboxone_fw2015_init),
>  	XBOXONE_INIT_PKT(0x0e6f, 0x02ab, xboxone_pdp_init1),
>  	XBOXONE_INIT_PKT(0x0e6f, 0x02ab, xboxone_pdp_init2),
> +	XBOXONE_INIT_PKT(0x0e6f, 0x02a4, xboxone_pdp_init1),
> +	XBOXONE_INIT_PKT(0x0e6f, 0x02a4, xboxone_pdp_init2),
>  	XBOXONE_INIT_PKT(0x24c6, 0x541a, xboxone_rumblebegin_init),
>  	XBOXONE_INIT_PKT(0x24c6, 0x542a, xboxone_rumblebegin_init),
>  	XBOXONE_INIT_PKT(0x24c6, 0x543a, xboxone_rumblebegin_init),
> -- 
> 2.16.2
>
diff mbox

Patch

diff --git a/drivers/input/joystick/xpad.c b/drivers/input/joystick/xpad.c
index 9d2688f3f961..5402f488bdb9 100644
--- a/drivers/input/joystick/xpad.c
+++ b/drivers/input/joystick/xpad.c
@@ -227,6 +227,7 @@  static const struct xpad_device {
 	{ 0x0e6f, 0x021f, "Rock Candy Gamepad for Xbox 360", 0, XTYPE_XBOX360 },
 	{ 0x0e6f, 0x0246, "Rock Candy Gamepad for Xbox One 2015", 0, XTYPE_XBOXONE },
 	{ 0x0e6f, 0x02ab, "PDP Controller for Xbox One", 0, XTYPE_XBOXONE },
+	{ 0x0e6f, 0x02a4, "PDP Wired Controller for Xbox One - Stealth Series", 0, XTYPE_XBOXONE },
 	{ 0x0e6f, 0x0301, "Logic3 Controller", 0, XTYPE_XBOX360 },
 	{ 0x0e6f, 0x0346, "Rock Candy Gamepad for Xbox One 2016", 0, XTYPE_XBOXONE },
 	{ 0x0e6f, 0x0401, "Logic3 Controller", 0, XTYPE_XBOX360 },
@@ -475,7 +476,8 @@  static const u8 xboxone_hori_init[] = {
 
 /*
  * This packet is required for some of the PDP pads to start
  * sending input reports. One of those pads is (0x0e6f:0x02ab).
  */
 static const u8 xboxone_pdp_init1[] = {
 	0x0a, 0x20, 0x00, 0x03, 0x00, 0x01, 0x14
@@ -483,7 +485,8 @@  static const u8 xboxone_pdp_init1[] = {
 
 /*
  * This packet is required for some of the PDP pads to start
  * sending input reports. One of those pads is (0x0e6f:0x02ab).
  */
 static const u8 xboxone_pdp_init2[] = {
 	0x06, 0x20, 0x00, 0x02, 0x01, 0x00
@@ -521,6 +524,8 @@  static const struct xboxone_init_packet xboxone_init_packets[] = {
 	XBOXONE_INIT_PKT(0x0000, 0x0000, xboxone_fw2015_init),
 	XBOXONE_INIT_PKT(0x0e6f, 0x02ab, xboxone_pdp_init1),
 	XBOXONE_INIT_PKT(0x0e6f, 0x02ab, xboxone_pdp_init2),
+	XBOXONE_INIT_PKT(0x0e6f, 0x02a4, xboxone_pdp_init1),
+	XBOXONE_INIT_PKT(0x0e6f, 0x02a4, xboxone_pdp_init2),
 	XBOXONE_INIT_PKT(0x24c6, 0x541a, xboxone_rumblebegin_init),
 	XBOXONE_INIT_PKT(0x24c6, 0x542a, xboxone_rumblebegin_init),
 	XBOXONE_INIT_PKT(0x24c6, 0x543a, xboxone_rumblebegin_init),
@@ -475,7 +476,8 @@  static const u8 xboxone_hori_init[] = {
 /*
  * This packet is required for some of the PDP pads to start
- * sending input reports. One of those pads is (0x0e6f:0x02ab).
+ * sending input reports. These pads include : (0x0e6f:0x02ab,
+ * 0x0e6f:0x02a4).
  */
 static const u8 xboxone_pdp_init1[] = {
@@ -483,7 +485,8 @@  static const u8 xboxone_pdp_init1[] = {
 /*
  * This packet is required for some of the PDP pads to start
- * sending input reports. One of those pads is (0x0e6f:0x02ab).
+ * sending input reports. These pads include : (0x0e6f:0x02ab,
+ * 0x0e6f:0x02a4).
  */
 static const u8 xboxone_pdp_init2[] = {